@@ -7,7 +7,7 @@ use AI::NNFlex::Dataset;
 # Create the network 
 
 my $network = AI::NNFlex::Backprop->new(
-				learningrate=>.15,
+				learningrate=>.2,
 				bias=>1,
 				fahlmanconstant=>0.1,
 				momentum=>0.6,
@@ -34,15 +34,17 @@ my $dataset = AI::NNFlex::Dataset->new([
 			[1,0],[1],
 			[1,1],[0]]);
 
+$dataset->save(filename=>'xor.pat');
+$dataset->load(filename=>'xor.pat');
 
 
 my $counter=0;
 my $err = 10;
 while ($err >.001)
+#for (1..1500)
 {
 	$err = $dataset->learn($network);
-
-	print "Epoch $counter: Error = $err\n";
+	print "Epoch = $counter error = $err\n";
 	$counter++;
 }
 
@@ -53,5 +55,5 @@ foreach (@{$dataset->run($network)})
 	print "\n";	
 }
 
-
+print "this should be 1 - ".@{$network->run([0,1])}."\n";
 
