@@ -2,14 +2,15 @@
 # and minimal set of parameters (using default values)
 
 use strict;
-use AI::NNFlex::momentum;
+use AI::NNFlex::Backprop;
 use AI::NNFlex::Dataset;
 
 # Create the network 
 
-my $network = AI::NNFlex::momentum->new( learningrate=>.1,
+my $network = AI::NNFlex::Backprop->new( learningrate=>.1,
 				bias=>1,
 				momentum=>0.6,
+				fahlmanconstant=>0.1,
 				round=>1);
 
 
